import requests
from typing import List
from zcc_utils import time_utils


if __name__ == "__main__":
    # time_local = time.localtime(1620557507)
    # print(type(time_local))
    # print(time_local)
    print(time_utils.float_hour_to_time(12.99))